Learn R Programming

tpAUC (version 2.1.1)

podc.ci: Partial ODC Inference

Description

Infer the area of region under ordinal dominance curve with pre-specific FNR constraint (FNR-pODC). See http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html for details.

Usage

podc.ci(response, predictor, cp = 0.95, threshold = 0.9, method = "MW")

Arguments

response
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative.
predictor
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric.
cp
numeric; coverage probability of confidence interval.
threshold
numeric; false negative rate (FNR) constraint.
method
methods to estimate partial ODC. MW: Mann-Whitney statistic. expect: method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html adapted from http://www.ncbi.nlm.nih.gov/pubmed/20729218. jackknife: jackknife method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html.

Value

Confidence interval of FNR partial ODC.

Details

This function infers FNR partial ODC given response, predictor and pre-specific FNR constraint. MW: Mann-Whitney statistic. expect: method in (2.2) http://www.ncbi.nlm.nih.gov/pubmed/20729218. jackknife: jackknife method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html.

See Also

proc.ci

Examples

Run this code

library('pROC')
data(aSAH)
podc.ci(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8, cp=0.97)

Run the code above in your browser using DataLab