Learn R Programming

tpAUC (version 2.1.1)

podc.est: Partial ODC Estimation

Description

Estimate the area of region under ordinal dominance curve with pre-specific FNR constraint (FNR-pODC). See http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html for details.

Usage

podc.est(response, predictor, threshold = 0.9, method = "MW",
  smooth = FALSE)

Arguments

response
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative.
predictor
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric.
threshold
numeric; false negative rate (FNR) constraint.
method
methods to estimate partial ODC. MW: Mann-Whitney statistic. expect: method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html adapted from http://www.ncbi.nlm.nih.gov/pubmed/20729218. jackknife: jackknife method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html.
smooth
if TRUE, the ODC curve is passed to smooth to be smoothed.

Value

Estimation of FNR partial ODC.

Details

This function estimates FNR partial ODC given response, predictor and pre-specific FNR constraint. MW: Mann-Whitney statistic. expect: method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html adapted from http://www.ncbi.nlm.nih.gov/pubmed/20729218. jackknife: jackknife method in http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html.

See Also

proc.est

Examples

Run this code

library('pROC')
data(aSAH)
podc.est(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8 )

Run the code above in your browser using DataLab